@@ -24,7 +24,7 @@ class ClinicalQualityMeasure138v6p2(ClinicalQualityMeasure138v6):
         description = ('Patients aged 18 years and older, and identified as a tobacco user, '
                        'who have not received tobacco cessation intervention such as counselling, '
                        'referral or medication.')
-        information = 'https://ecqi.healthit.gov/ecqm/measures/cms138v6'
+        information = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS138v6.html'
 
         identifiers = ['CMS138v6p2']
 
