@@ -13,6 +13,8 @@ from canvas_workflow_kit.patient_recordset import (
     PatientRecordSet,
     BillingLineItemRecordSet,
     ConditionRecordSet,
+    ConsentRecordSet,
+    GroupRecordSet,
     ImagingReportRecordSet,
     ImmunizationRecordSet,
     InpatientStayRecordSet,
@@ -27,6 +29,7 @@ from canvas_workflow_kit.patient_recordset import (
     ReasonForVisitRecordSet,
     ReferralRecordSet,
     ReferralReportRecordSet,
+    TaskRecordSet,
     UpcomingAppointmentNoteRecordSet,
     UpcomingAppointmentRecordSet,
     VitalSignRecordSet
@@ -59,6 +62,8 @@ class Patient:
         AllergyIntoleranceRecordSet,
         BillingLineItemRecordSet,
         ConditionRecordSet,
+        ConsentRecordSet,
+        GroupRecordSet,
         ImagingReportRecordSet,
         ImmunizationRecordSet,
         InpatientStayRecordSet,
@@ -72,6 +77,7 @@ class Patient:
         ReasonForVisitRecordSet,
         ReferralRecordSet,
         ReferralReportRecordSet,
+        TaskRecordSet,
         UpcomingAppointmentNoteRecordSet,
         UpcomingAppointmentRecordSet,
         VitalSignRecordSet,
@@ -94,6 +100,12 @@ class Patient:
         self.conditions = ConditionRecordSet.new_from(
             data.get(ConditionRecordSet.API_UPDATE_FIELD, []))
 
+        self.consents = ConsentRecordSet.new_from(
+            data.get(ConsentRecordSet.API_UPDATE_FIELD, []))
+
+        self.groups = GroupRecordSet.new_from(
+            data.get(GroupRecordSet.API_UPDATE_FIELD, []))
+
         self.imaging_reports = ImagingReportRecordSet.new_from(
             data.get(ImagingReportRecordSet.API_UPDATE_FIELD, []))
 
@@ -138,6 +150,9 @@ class Patient:
 
         self.suspect_hccs = data.get('suspectHccs', [])
 
+        self.tasks = TaskRecordSet.new_from(
+            data.get(TaskRecordSet.API_UPDATE_FIELD, []))
+
         self.upcoming_appointments = UpcomingAppointmentRecordSet.new_from(
             data.get(UpcomingAppointmentRecordSet.API_UPDATE_FIELD))
 
