@@ -505,6 +505,12 @@ class ConditionRecordSet(PatientPeriodRecordSet):
         return []
 
 
+class ConsentRecordSet(PatientRecordSet):
+    VALID_SYSTEMS: List[str] = ['canvas', 'internal']
+    PATIENT_FIELD = 'consents'
+    API_UPDATE_FIELD = 'consents'
+
+
 class ImmunizationRecordSet(PatientEventRecordSet):
     VALID_SYSTEMS = ['cvx']
     DATE_FIELD = 'dateOrdered'
@@ -779,6 +785,12 @@ class ReasonForVisitRecordSet(PatientEventRecordSet):
     API_UPDATE_FIELD = 'reasonForVisits'
 
 
+class TaskRecordSet(PatientRecordSet):
+    VALID_SYSTEMS: List[str] = ['canvas', 'internal']
+    PATIENT_FIELD = 'tasks'
+    API_UPDATE_FIELD = 'tasks'
+
+
 class UpcomingAppointmentRecordSet(PatientRecordSet):
     VALID_SYSTEMS: List[str] = ['canvas', 'internal']
     PATIENT_FIELD = 'upcoming_appointments'
@@ -810,3 +822,8 @@ class AdministrativeDocumentRecordSet(PatientEventRecordSet):
     PATIENT_FIELD = 'administrative_documents'
     API_UPDATE_FIELD = 'administrativeDocuments'
     DATE_FIELD = 'originalDate'
+
+class GroupRecordSet(PatientRecordSet):
+    PATIENT_FIELD = 'groups'
+    API_UPDATE_FIELD = 'groups'
+
