@@ -5,6 +5,8 @@ from unittest import TestCase
 from canvas_workflow_kit.patient_recordset import (
     BillingLineItemRecordSet,
     ConditionRecordSet,
+    ConsentRecordSet,
+    GroupRecordSet,
     ImagingReportRecordSet,
     ImmunizationRecordSet,
     InstructionRecordSet,
@@ -18,6 +20,7 @@ from canvas_workflow_kit.patient_recordset import (
     ProtocolOverrideRecordSet,
     PrescriptionRecordSet,
     ReferralReportRecordSet,
+    TaskRecordSet,
     VitalSignRecordSet
 )
 from canvas_workflow_kit.timeframe import Timeframe
@@ -1660,6 +1663,31 @@ class TestImagingReportRecordSet(TestCase):
         ]
         self.assertEqual(expected, ImagingReportRecordSet.item_to_codes(item))
 
+class TestConsentRecordSet(TestCase):
+
+    def test_constants(self):
+        tested = ConsentRecordSet([])
+        self.assertIsInstance(tested, PatientRecordSet)
+        self.assertEqual(['canvas', 'internal'], tested.VALID_SYSTEMS)
+        self.assertEqual('consents', tested.PATIENT_FIELD)
+        self.assertEqual('consents', tested.API_UPDATE_FIELD)
+
+class TestGroupRecordSet(TestCase):
+
+    def test_constants(self):
+        tested = GroupRecordSet([])
+        self.assertIsInstance(tested, PatientRecordSet)
+        self.assertEqual('groups', tested.PATIENT_FIELD)
+        self.assertEqual('groups', tested.API_UPDATE_FIELD)
+
+class TestTaskRecordSet(TestCase):
+
+    def test_constants(self):
+        tested = TaskRecordSet([])
+        self.assertIsInstance(tested, PatientRecordSet)
+        self.assertEqual(['canvas', 'internal'], tested.VALID_SYSTEMS)
+        self.assertEqual('tasks', tested.PATIENT_FIELD)
+        self.assertEqual('tasks', tested.API_UPDATE_FIELD)
 
 class TestProcedureRecordSet(TestCase):
 
