@@ -12,7 +12,7 @@ from canvas_workflow_kit.protocol import (
     get_subclasses,
     protocols_for_patient
 )
-from canvas_workflow_kit.recommendation import Recommendation
+from canvas_workflow_kit.recommendation import Recommendation, PlanRecommendation
 from canvas_workflow_kit.tests import get_protocols_unittest
 from canvas_workflow_kit.timeframe import Timeframe
 
@@ -39,9 +39,11 @@ class TestProtocolResult(SDKBaseTest):
             Recommendation('KEY-A', 7, 'ACT', 'reco A', 'this is the reco A'))
         tested.add_recommendation(
             Recommendation('KEY-B', 3, 'BAC', 'reco B', 'this is the reco B'))
-        self.assertEqual(2, len(tested.recommendations))
+        tested.add_recommendation(
+            PlanRecommendation('KEY-C', 4, 'BAC', 'button', 'reco C', 'this is the reco C'))
+        self.assertEqual(3, len(tested.recommendations))
         for recommendation in tested.recommendations:
-            self.assertIn(recommendation.title, ['reco A', 'reco B'])
+            self.assertIn(recommendation.title, ['reco A', 'reco B', 'reco C'])
 
     def test_add_recommendation_shorthand(self):
         tested = ProtocolResult()
@@ -49,7 +51,7 @@ class TestProtocolResult(SDKBaseTest):
         tested.add_recommendation(
             'KEY-A', 7, 'ACT', 'reco A', 'this is the reco A')
         tested.add_recommendation(
-            'KEY-B', 3, 'BAC', 'reco B', 'this is the reco B')
+            key='KEY-B', rank=3, button='BAC', title='reco B', narrative='this is the reco B')
         self.assertEqual(2, len(tested.recommendations))
         for recommendation in tested.recommendations:
             self.assertIn(recommendation.title, ['reco A', 'reco B'])
